uboat
*****

This library helps you write command-line python scripts to use sub commands 
(e.g. "git commit", "git checkout"). It is a thin wrapper around the built-in
library argparse.

This was written before the author discovered the vastly superior:
`click <https://click.palletsprojects.com>`_. You should use that instead.

Installation
============

.. code-block:: bash

    $ pip install uboat

Supports
========

uboat has been tested with Python 3.6 and 3.7

Docs & Source
=============

Docs: http://uboat.readthedocs.io/en/latest/

Source: https://github.com/cltrudeau/uboat
